package com.example.horseracing

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.View
import android.widget.Button
import android.widget.ImageView
import android.widget.ArrayAdapter
import android.widget.AdapterView
import android.widget.Spinner
import android.widget.TextView
import android.widget.Toast
import java.nio.charset.Charset
import org.json.JSONObject
import org.json.JSONException
import kotlin.collections.ArrayList
import android.content.Intent
import android.net.Uri

class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val tvSire = findViewById<TextView>(R.id.tvSire)
        val tvTrainer = findViewById<TextView>(R.id.tvTrainer)
        val ivSilks = findViewById<ImageView>(R.id.ivSilks)
        val btnClip = findViewById<Button>(R.id.btnClip)
        val spHorse = findViewById<Spinner>(R.id.spHorse)

        // read the file from raw resource
        val input_stream = baseContext.resources.openRawResource(R.raw.horseracing)
        var horse_text = input_stream.readBytes().toString(Charset.defaultCharset())

        // note that the json file starts with a { meaning it starts with an object
        // that object has a property called horses and horses is an array of objects
        val myJSON_object = JSONObject(horse_text)
        var myJSON_array = myJSON_object.getJSONArray("horses")

        // horse names to be used in conjunction with spinner
        val horse_rank_and_name: MutableList<String> = ArrayList()

        // loop over array extract horse name and rank add to
        for(i in 0..(myJSON_array.length() - 1)){
            //Toast.makeText(this,myJSON_array.getJSONObject(i).getString("horseName"),Toast.LENGTH_LONG).show()
            //get the individual properties of the JSON element
            val horse_rank = myJSON_array.getJSONObject(i).getString("horseRank")
            val horse_name = myJSON_array.getJSONObject(i).getString("horseName")
            //make the horse rank & name combo
            horse_rank_and_name.add( "$horse_rank. $horse_name")
        }

        //*****************************************************************************************************
        val aaHorse = ArrayAdapter(this, android.R.layout.simple_spinner_item, horse_rank_and_name)
        aaHorse.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item) // The drop down view
        spHorse.adapter = aaHorse

        spHorse.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
            override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {
                val tvUserItem = view as TextView
                Toast.makeText(applicationContext, "You chose " + tvUserItem.text.toString(), Toast.LENGTH_SHORT).show()

                tvSire.text = "  " + myJSON_array.getJSONObject(i).getString("horseSire")
                tvTrainer.text = "  " + myJSON_array.getJSONObject(i).getString("horseTrainer")
                val iv_id = resources.getIdentifier(
                    myJSON_array.getJSONObject(i).getString("horseSilks"), "drawable",
                     packageName)
                ivSilks.setImageResource(iv_id)
            }

            override fun onNothingSelected(adapterView: AdapterView<*>) {}
        } //end onItemSelectedListener

        //**********************************************************************************************
        btnClip.setOnClickListener {
            val id = spHorse.selectedItemPosition
            //Toast.makeText(getApplicationContext(), ""+id, Toast.LENGTH_LONG).show();

            try {
                val ytc = myJSON_array.getJSONObject(id).getString("horseYouTubeCode")
                //Toast.makeText(getApplicationContext(), ytc, Toast.LENGTH_LONG).show();
                startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("https://www.youtube.com/watch?v=$ytc")))
            } catch (e: JSONException) {

            }
        }//end setOnClickListener

    } //end onCreate
} //end MainActivity class